# Copyright (c) 2000-2011, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support
%bcond_without repolib

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define version_full %{version}%{reltag}

%define repodir %{_javadir}/repository.jboss.com/hsqldb/%{version_full}
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define reltag -patch-01
%define brewreltag _patch_01

%define section		devel

%define cvs_version	1_8_0_10

Name:		hsqldb
Version:	1.8.0.10
Release:        9%{brewreltag}.2%{?dist}
Epoch:		1
Summary:	Hsqldb Database Engine
License:	BSD
Url:		http://hsqldb.sourceforge.net/
#http://downloads.sourceforge.net/hsqldb/hsqldb_1_8_0_9.zip
Source0:	%{name}_%{cvs_version}.zip
Source1:	%{name}-1.8.0-standard.cfg
Source2:	%{name}-1.8.0-standard-server.properties
Source3:	%{name}-1.8.0-standard-webserver.properties
Source4:	%{name}-1.8.0-standard-sqltool.rc
Source5:        hsqldb-component-info.xml
# Adjusted http://repository.jboss.org/maven2/hsqldb/hsqldb/1.8.0.8patch01-brew/hsqldb-1.8.0.8patch01-brew.pom to change the version for 1.8.0.10-patch-01
Source6:        hsqldb.pom
Patch0:		%{name}-1.8.0-scripts.patch
Patch1:		hsqldb-tmp.patch
Patch2:		hsqldb-initscript.patch
Patch3:		%{name}-1.8.0-bitxor-bitor.patch
Patch4:		%{name}-1.8.0-autoincrement.patch
#Patch to fix MANIFEST to show version properly
# This patch file needs to be updated if the version is no longer
# 1.8.0.8.patch02
Patch5:         hsqldb-1.8.0.10-manifest.patch
Patch6:         hsqldb-1.8.0.10-JBPAPP-3189.patch
Requires(post):	/bin/rm,/bin/ln
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires(preun): /bin/rm
Requires(pre):	shadow-utils
Requires:       jpackage-utils
Requires:       servlet_2_5_api
BuildRequires:	ant
BuildRequires:	junit
BuildRequires:	jpackage-utils >= 0:1.5
BuildRequires:  jboss-parent
BuildRequires:  maven-buildmagic-thirdparty-plugin
BuildRequires:  servlet_2_5_api
Group:		Applications/Databases
%if %{gcj_support}
BuildRequires:		java-gcj-compat-devel
Requires(post):		java-gcj-compat
Requires(postun):	java-gcj-compat
%else
Buildarch:	noarch
%endif
BuildRoot:	%{_tmppath}/%{name}-%{version}-buildroot

%description
HSQLdb is a relational database engine written in JavaTM , with a JDBC
driver, supporting a subset of ANSI-92 SQL. It offers a small (about
100k), fast database engine which offers both in memory and disk based
tables. Embedded and server modes are available. Additionally, it
includes tools such as a minimal web server, in-memory query and
management tools (can be run as applets or servlets, too) and a number
of demonstration examples.

Downloaded code should be regarded as being of production quality. The
product is currently being used as a database and persistence engine in
many Open Source Software projects and even in commercial projects and
products! In it's current version it is extremely stable and reliable.
It is best known for its small size, ability to execute completely in
memory and its speed. Yet it is a completely functional relational
database management system that is completely free under the Modified
BSD License. Yes, that's right, completely free of cost or restrictions!

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%package manual
Summary:	Manual for %{name}
Group:		Applications/Databases

%description manual
Documentation for %{name}.

%package javadoc
Summary:	Javadoc for %{name}
Group:		Applications/Databases
# For /bin/rm and /bin/ln
Requires(post):	coreutils
Requires(preun):coreutils
Requires:       jpackage-utils

%description javadoc
Javadoc for %{name}.

%package demo
Summary:	Demo for %{name}
Group:		Applications/Databases
Requires:	%{name} = %{epoch}:%{version}-%{release}

%description demo
Demonstrations and samples for %{name}.

%prep
%setup -q -n %{name}

perl -pi -e 's/\r$//g' doc/*.txt doc/src/hsqldbstylesheet.css

cp -p %{SOURCE6} hsqldb.pom
sed -i 's/@VERSION@/%{version_full}/g' hsqldb.pom

# set right permissions
find . -name "*.sh" -exec chmod 755 \{\} \;
# remove all _notes directories
for dir in `find . -name _notes`; do rm -rf $dir; done
# remove all binary libs
find . -name "*.jar" -exec rm -f {} \;
find . -name "*.class" -exec rm -f {} \;
find . -name "*.war" -exec rm -f {} \;
# correct silly permissions
chmod -R go=u-w *

%patch0
%patch1 -p1
%patch2 -p2
%patch3 -p8
%patch4 -p3
%patch5 -p0
%patch6 -p1

%build
export CLASSPATH=$(build-classpath \
jsse/jsse \
jsse/jnet \
jsse/jcert \
jdbc-stdext \
servlet_2_5_api \
junit)
export OPT_JAR_LIST=:
pushd build
%{ant} -Dbuild.sysclasspath=first jar javadoc
popd

%install
rm -rf %{buildroot}

# jar
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -m 644 lib/%{name}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} ${jar/-%{version}/}; done)
# bin
install -d -m 755 $RPM_BUILD_ROOT%{_bindir}
install -m 755 bin/runUtil.sh $RPM_BUILD_ROOT%{_bindir}/%{name}RunUtil
# sysv init
install -d -m 755 $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d
install -m 755 bin/%{name} $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/%{name}
# config
install -d -m 755 $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
install -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/%{name}
# serverconfig
install -d -m 755 $RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}
install -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}/server.properties
install -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}/webserver.properties
install -m 600 %{SOURCE4} $RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}/sqltool.rc
# lib
install -d -m 755 $RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}/lib
install -m 644 lib/functions $RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}/lib
# data
install -d -m 755 $RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}/data
# demo
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/%{name}/demo
install -m 755 demo/*.sh $RPM_BUILD_ROOT%{_datadir}/%{name}/demo
install -m 644 demo/*.html $RPM_BUILD_ROOT%{_datadir}/%{name}/demo
# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -r doc/src/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}
rm -rf doc/src
# manual
install -d -m 755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -r doc/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp index.html $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

%{__mkdir_p} %{buildroot}%{_datadir}/maven2/poms
%{__cp} -p hsqldb.pom %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap hsqldb hsqldb %{version_full} JPP %{name}

(cd %{buildroot}%{_localstatedir}/lib/%{name}/lib
    ln -s %{_javadir}/hsqldb.jar hsqldb.jar
    ln -s %{_javadir}/servlet_2_5_api.jar servlet.jar
) || :

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%if %with repolib
install -d -m 755 $RPM_BUILD_ROOT%{repodir}
install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
install -p -m 644 %{SOURCE5} $RPM_BUILD_ROOT%{repodir}/component-info.xml
sed -i 's/@VERSION@/%{version_full}/g' $RPM_BUILD_ROOT%{repodir}/component-info.xml
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" $RPM_BUILD_ROOT%{repodir}/component-info.xml
install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{PATCH0} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{PATCH1} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{PATCH2} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{PATCH3} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{PATCH4} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{PATCH5} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{PATCH6} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
cp -p $RPM_BUILD_ROOT%{_javadir}/hsqldb.jar $RPM_BUILD_ROOT%{repodirlib}/hsqldb.jar
cp -p %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom $RPM_BUILD_ROOT%{repodirlib}/hsqldb.pom
install -d -m 755 %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew
pushd $RPM_BUILD_ROOT%{repodir}
%{_bindir}/mvn-jpp -e \
        org.jboss.maven.plugins:maven-buildmagic-thirdparty-plugin:maven-deploy\
        -Durl=file://%{buildroot}%{_javadir}/repository.jboss.com/maven2-brew
popd
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%pre
# Add the "hsqldb" user and group
# we need a shell to be able to use su - later
%{_sbindir}/groupadd -g 96 -f -r %{name} 2> /dev/null || :
%{_sbindir}/useradd -u 96 -g %{name} -s /sbin/nologin \
    -d %{_localstatedir}/lib/%{name} -r %{name} 2> /dev/null || :

%post
rm -f %{_localstatedir}/lib/%{name}/lib/hsqldb.jar
rm -f %{_localstatedir}/lib/%{name}/lib/servlet.jar
(cd %{_localstatedir}/lib/%{name}/lib
    ln -s $(build-classpath hsqldb) hsqldb.jar
    ln -s $(build-classpath servlet_2_5_api) servlet.jar
)

%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif
%update_maven_depmap

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%preun
if [ "$1" = "0" ]; then
    rm -f %{_localstatedir}/lib/%{name}/lib/hsqldb.jar
    rm -f %{_localstatedir}/lib/%{name}/lib/servlet.jar
    #%{_sbindir}/userdel %{name} >> /dev/null 2>&1 || :
    #%{_sbindir}/groupdel %{name} >> /dev/null 2>&1 || :
fi

%files
%defattr(0644,root,root,0755)
%dir %{_docdir}/%{name}-%{version}
%doc %{_docdir}/%{name}-%{version}/hsqldb_lic.txt
%{_javadir}*/%{name}-%{version}.jar
%{_javadir}*/%{name}.jar
%attr(0755,root,root) %{_bindir}/*
%attr(0755,root,root) %{_sysconfdir}/rc.d/init.d/%{name}
%attr(0644,root,root) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/sysconfig/%{name}
%attr(0755,hsqldb,hsqldb) %{_localstatedir}/lib/%{name}/data
%{_localstatedir}/lib/%{name}/lib
%{_localstatedir}/lib/%{name}/lib/functions
%{_localstatedir}/lib/%{name}/lib/hsqldb.jar
%{_localstatedir}/lib/%{name}/lib/servlet.jar
%attr(0644,root,root) %{_localstatedir}/lib/%{name}/server.properties
%attr(0644,root,root) %{_localstatedir}/lib/%{name}/webserver.properties
%attr(0600,hsqldb,hsqldb) %{_localstatedir}/lib/%{name}/sqltool.rc
%dir %{_localstatedir}/lib/%{name}
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}
%if %{gcj_support}
%dir %{_libdir}/gcj
%attr(-,root,root) %{_libdir}/gcj/%{name}
%endif

%files manual
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-%{version}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%files demo
%defattr(0644,root,root,0755)
%{_datadir}/%{name}

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}
%exclude %{_javadocdir}
%{_javadir}/repository.jboss.com
%endif

%changelog
* Wed May 25 2011 David Walluck <dwalluck@redhat.com> 1:1.8.0.10-9_patch_01.2
- change build-classpath to %%_javadir in install
- remove obsolete javadoc %%post and %postun scriptlets
- fix repolib dir ownership

* Tue Apr 12 2011 Martha Benitez <mbenitez@redhat.com> - 1:1.8.0.10-9_patch_01.1
- Fix servlet symlink

* Wed Mar 23 2011 Martha Benitez <mbenitez@redhat.com> - 1:1.8.0.10-9_patch_01
- Merge from RHEL6 branch
- Fix release number to make it newer than base

* Mon Mar 21 2011 Martha Benitez <mbenitez@redhat.com> - 1:1.8.0.10-4_patch_01
- Include patches from 1.8.0.8-patch-03
- Adjust JBPAPP-3189.patch for 1.8.0.10 version
- Add maven2-brew contents to repolib

* Thu Sep 02 2010 Martha Benitez <mbenitez@redhat.com> 1:1.8.0.8-3.patch03.2
- Rebuild

* Mon Jul 12 2010 David Walluck <dwalluck@redhat.com> 1:1.8.0.8-3.patch03.1
- add hsqldb-1.8.0.8-JBPAPP-3189.patch
- use servletapi4 for build and servlet_2_5_api for runtime
- create symlinks during install, not postinstall
- fix GCJ support option

* Wed Jun 30 2010 David Walluck <dwalluck@redhat.com> 1:1.8.0.8-2.patch02.4
- add Requires(post): jpackage-utils to fix postin scriptlet
- fix install (remove build root)
- fix javadoc dir ownership
- remove javadoc scriptlets
- fix doc copy not to break short-circuit
- fix component-info.xml in repolib
- fix repolib dir ownership
- fix repolib permissions
- fix GCJ support

* Thu May 06 2010 Martha Benitez <mbenitez@redhat.com> - 1:1.8.0.8-2.patch02.3.1
- rebuilt
- Add verbose, debug options to build

* Mon Apr 19 2010 Yiqiao Wang <yiwang@redhat.com> 1:1.8.0.8-2.patch02.3
- Rebuild

* Mon Mar 01 2010 Martha Benitez <mbenitez@redhat.com> 1:1.8.0.8-2.patch02.2
- Fix release tag
- Remove Vendor and Distribution

* Thu May 07 2009 Permaine Cheung <pcheung@redhat.com> 1:1.8.0.8-2.patch02.1jpp.ep1.2
- Rebuild

* Thu May 07 2009 Permaine Cheung <pcheung@redhat.com> 1:1.8.0.8-2.patch02.1jpp.ep1.1
- Change reltag to patch02
- Add patch to change MANIFEST to properly show version info [JBPAPP-1100]

* Tue Dec 18 2007 Fernando Nasser <fnasser@redhat.com> 1:1.8.0.8-2.patch01.1jpp.ep1.2
- Rename patch file for better description of contents

* Tue Dec 18 2007 Fernando Nasser <fnasser@redhat.com> 1:1.8.0.8-2.patch01.1jpp.ep1.1
- Change release to patch01

* Mon Dec 17 2007 Fernando Nasser <fnasser@redhat.com> 1:1.8.0.8-1jpp.ep1.6
- Add the backported patch to the src subdirectory in repolib
- Mention the fix in the component-info.xml file

* Mon Dec 17 2007 Fernando Nasser <fnasser@redhat.com> 1:1.8.0.8-1jpp.ep1.5
- Rebuild with JDK 1.4

* Tue Dec 04 2007 Jon Prindiville <jprindiv@redhat.com> 1:1.8.0.8-1jpp.ep1.4
- Merging changes from embargo branch addressing CVE-2007-4576 (#298051)

* Wed Nov 21 2007 Fernando Nasser <fnasser@redhat.com> 1:1.8.0.8-1jpp.ep1.3
- Fix repolibdir

* Fri Aug 31 2007 Fernando Nasser <fnasser@redhat.com> 1:1.8.0.8-1jpp.ep1.1
- Merge with usptream

* Fri Aug 31 2007 Fernando Nasser <fnasser@redhat.com> 1:1.8.0.8-1jpp
- Upgrade to 1.8.0.8

* Mon Feb 19 2007 Vivek Lakshmanan <vivekl@redhat.com> 1:1.8.0.7-2jpp.el4ep1.2
- Add -brew suffix

* Sat Feb 17 2007 Vivek Lakshmanan <vivekl@redhat.com> 1:1.8.0.7-2jpp.el4ep1.1
- Add repolib support

* Mon Jan 22 2007 Deepak Bhole <dbhole@redhat.com> 1:1.8.0.7-2jpp
- Update copyright date

* Thu Jan 11 2007 Deepak Bhole <dbhole@redhat.com> 1.8.0.7-1jpp
- Updgrade to 1.8.0.7

* Wed Nov 29 2006 Deepak Bhole <dbhole@redhat.com> 1.8.0.4-4jpp
- Added missing entries to the files section
- From fnasser@redhat.com:
  - Add post requires for servletapi5 to ensure installation order
- From sgrubb@redhat.com:
  - Apply patch correcting tmp file usage

* Mon Aug 21 2006 Deepak Bhole <dbhole@redhat.com> 1:1.8.0.4-3jpp
- Add missing postun section.

* Fri Aug 04 2006 Deepak Bhole <dbhole@redhat.com> 1:1.8.0.4-2jpp
- Add missing requirements.
- Merge with fc spec.
  - From gbenson@redhat.com:
    - Change /etc/init.d to /etc/rc.d/init.d.
    - Create hsqldb user and group with low IDs (RH bz #165670).
    - Do not remove hsqldb user and group on uninstall.
    - Build with servletapi5.
  - From ashah@redhat.com:
    - Change hsqldb user shell to /sbin/nologin.
  - From notting@redhat.com
    - use an assigned user/group id

* Fri Apr 28 2006 Fernando Nasser <fnasser@redhat.com> 1:1.8.0.4-1jpp
- First JPP 1.7 build
- Upgrade to 1.8.0.4

* Tue Jul 26 2005 Fernando Nasser <fnasser@redhat.com> 0:1.80.1-1jpp
- Upgrade to 1.8.0.1

* Mon Mar 07 2005 Fernando Nasser <fnasser@redhat.com> 0:1.73.3-1jpp
- Upgrade to 1.7.3.3

* Wed Mar 02 2005 Fernando Nasser <fnasser@redhat.com> 0:1.73.0-1jpp
- Upgrade to 1.7.3.0

* Wed Aug 25 2004 Ralph Apel <r.apel at r-apel.de> 0:1.72.3-2jpp
- Build with ant-1.6.2

* Mon Aug 16 2004 Ralph Apel <r.apel at r-apel.de> 0:1.72.3-1jpp
- 1.7.2.3 stable

* Fri Jun 04 2004 Ralph Apel <r.apel at r-apel.de> 0:1.72-0.rc6b.1jpp
- 1.7.2 preview

* Tue May 06 2003 David Walluck <david@anti-microsoft.org> 0:1.71-1jpp
- 1.71
- update for JPackage 1.5

* Mon Mar 18 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.61-6jpp 
- generic servlet support

* Mon Jan 21 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.61-5jpp 
- versioned dir for javadoc
- no dependencies for javadoc package
- stricter dependencies for demo package
- section macro
- adaptation to new servlet3 package

* Mon Dec 17 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.61-4jpp
- javadoc in javadoc package
- doc reorganisation
- removed Requires: ant
- patches regenerated and bzipped

* Wed Nov 21 2001 Christian Zoffoli <czoffoli@littlepenguin.org> 1.61-3jpp
- removed packager tag
- new jpp extension

* Fri Nov 09 2001 Christian Zoffoli <czoffoli@littlepenguin.org> 1.61-2jpp
- added BuildRequires: servletapi3 ant
- added Requires: servletapi3 ant

* Fri Nov 09 2001 Christian Zoffoli <czoffoli@littlepenguin.org> 1.61-1jpp
- complete spec restyle
- splitted & improved linuxization patch

* Fri Nov 09 2001 Christian Zoffoli <czoffoli@littlepenguin.org> 1.60-1jpp
- 1.60 first "official release" of Hsqldb

* Fri Nov 09 2001 Christian Zoffoli <czoffoli@littlepenguin.org> 1.43-2jpp
- fixed version

* Fri Nov 09 2001 Christian Zoffoli <czoffoli@littlepenguin.org> 1.43-1jpp
- first release
- linuxization patch (doc + script)

